@@ -66,9 +66,15 @@ define([
       overlay: undefined,
 
       // timeouts
+      // wait for that amont before calling ensure_focused on the
+      // selected cell
       restore_timeout: 500,
+      // wait for that amount before actually selected auto-selected fragment
       // when going too short, like 250, size of selected cell get odd
-      auto_select_timeout: 500,
+      auto_select_timeout: 450,
+      // wait for that amount before calling sync() again
+      // this is a workaround that fixes #504
+      sync_timeout: 250,
 
       // UI
       toolbar_icon: 'fa-bar-chart',
@@ -85,7 +91,7 @@ define([
       },
 
       // reveal native settings passed as-is
-      // see also the 'inherited' variable below in Revealer below
+      // see also the 'inherited' variable below in Revealer
       theme: 'simple',
       transition: 'linear',
       // xxx there might be a need to tweak this one when set
@@ -345,6 +351,14 @@ define([
       Reveal.slide(0, 0);
     }
     setScrollingSlide();
+    // warkaround for #504
+    // when editing if you swap out of reveal, and then
+    // come back in, with 5.6 most of the time display 
+    // becomes empty or the contents is way too low
+    // this patch makes the situation much better,
+    // although it is clearly suboptimal to have 
+    // to resort to that sort of dirty patch
+    setTimeout(()=>Reveal.sync(), complete_config.sync_timeout);
   }
 
   /* Setup the scrolling in the current slide if the config option is activated
@@ -470,34 +484,28 @@ define([
     // Header
     // Available themes are in static/css/theme
     let theme = complete_config.theme;
-    $('head')
-      .prepend('<link rel="stylesheet" href='
-               + require.toUrl("./reveal.js/css/theme/" + theme + ".css")
-               + ' id="theme" />');
+    $('body').addClass(`theme-${theme}`);
+    let theme_path = `./reveal.js/css/theme/${theme}.css`;
+    $('head').prepend(
+      `<link rel="stylesheet" href="${require.toUrl(theme_path)}" id="theme" />`);
     // Add reveal css
-    $('head')
-      .prepend('<link rel="stylesheet" href='
-               + require.toUrl("./reveal.js/css/reveal.css")
-               + ' id="revealcss" />');
+    let main_path = "./reveal.js/css/reveal.css";
+    $('head').prepend(
+      `<link rel="stylesheet" href="${require.toUrl(main_path)}" id="revealcss" />`);
 
     /* this policy of trying ./rise.css and then <notebook>.css
      * should be redefinable in the config
      */
     if (window.location.pathname.endsWith('.ipynb')) {
-      // typically examples/README.ipynb
-      let path = Jupyter.notebook.notebook_path;
-      // typically README.ipynb
       let name = Jupyter.notebook.notebook_name;
-      // asscosiated css
+      // associated css
       let name_css = name.replace(".ipynb", ".css");
-      // typically /files/examples/
-      let prefix = `/files/${path.replace(name, '')}`;
       // Attempt to load rise.css
       $('head').append(
-          `<link rel="stylesheet" href="${prefix}rise.css" id="rise-custom-css" />`);
+          `<link rel="stylesheet" href="rise.css" id="rise-custom-css" />`);
       // Attempt to load css with the same path as notebook
       $('head').append(
-          `<link rel="stylesheet" href="${prefix}${name_css}" id="notebook-custom-css" />`);
+          `<link rel="stylesheet" href="${name_css}" id="rise-notebook-css" />`);
 
     }
 
@@ -507,7 +515,9 @@ define([
 
     // Tailer
     require([
-      './reveal.js/lib/js/head.min.js',
+      // no longer current
+      // https://github.com/hakimel/reveal.js/commit/29b0e86089eb3ec0d4bb5811c9b723dfcf36703c
+      // './reveal.js/lib/js/head.min.js',
       './reveal.js/js/reveal.js'
     ].map(require.toUrl),
             function(){
@@ -578,6 +588,9 @@ define([
               ////////// set up chalkboard if configured
               let enable_chalkboard = complete_config.enable_chalkboard;
               if (enable_chalkboard) {
+                if ("chalkboard" in complete_config) {
+                  options["chalkboard"] = complete_config["chalkboard"];
+                }
                 options.dependencies.push({ src: require.toUrl('./reveal.js-chalkboard/chalkboard.js'), async: true });
                 // xxx need to explore the option of registering jupyter actions
                 // and have jupyter handle the keyboard entirely instead of this approach
@@ -601,8 +614,8 @@ define([
                 //console.log("Reveal is already initialized and is being configured");
               } else {
                 Reveal.initialize(options);
-                Reveal["initialized"] = true;
                 //console.log("Reveal initialized");
+                Reveal.initialized = true;
               }
 
               Reveal.addEventListener('ready', function(event) {
@@ -800,6 +813,8 @@ define([
     Reveal.configure({minScale: 1.0});
     Reveal.removeEventListeners();
     $('body').removeClass("rise-enabled");
+    let theme = complete_config.theme;
+    $('body').removeClass(`theme-${theme}`);
     $('div#header').show();
 
     $('div#notebook').removeClass("reveal");
@@ -812,6 +827,8 @@ define([
 
     $('#theme').remove();
     $('#revealcss').remove();
+    $('#rise-custom-css').remove();
+    $('#rise-notebook-css').remove();
 
     $('.backgrounds').hide();
     $('.progress').hide();
